@@ -1,10 +1,6 @@
 OC.L10N.register(
     "deck",
     {
-    "Later" : "Later",
-    "copy" : "kopie",
-    "To Do" : "Moet doen",
-    "Done" : "Gereed",
     "The file was uploaded" : "Die lêer is opgelaai",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
@@ -12,12 +8,18 @@ OC.L10N.register(
     "No file was uploaded" : "Geen lêer is opgelaai",
     "Missing a temporary folder" : "Ontbrekende tydelike gids",
     "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
+    "Later" : "Later",
+    "copy" : "kopie",
+    "To Do" : "Moet doen",
+    "Done" : "Gereed",
+    "File" : "Lêer",
     "Cancel" : "Kanselleer",
     "File already exists" : "Lêer bestaan reeds",
     "Open" : "Open",
     "Completed" : "Voltooid",
     "Open details" : "Open besonderhede",
     "Details" : "Besonderhede",
+    "Search" : "Soek",
     "Tags" : "Etikette",
     "No participants found" : "Geen deelnemers gevind",
     "Can edit" : "Kan redigeer",
@@ -29,24 +31,24 @@ OC.L10N.register(
     "Modified" : "Gewysig",
     "Created" : "Geskep",
     "Comments" : "Kommentare",
-    "Save" : "Stoor",
     "Created:" : "Geskep:",
     "Reply" : "Antwoord",
     "Update" : "Werk by",
     "Description" : "Beskrywing",
     "Select Date" : "Kies Datum",
     "seconds ago" : "sekondes gelede",
-    "Keyboard shortcuts" : "Sneltoetse",
-    "Keyboard shortcut" : "Snelsleutel",
-    "Search" : "Soek",
     "Shared with you" : "Met u gedeel",
     "An error occurred" : "'n Fout het voorgekom",
     "No notifications" : "Geen kennisgewings",
     "Advanced options" : "Gevorderde opsies",
-    "Today" : "Vandag",
-    "Tomorrow" : "Môre",
-    "Close" : "Sluit",
+    "Export" : "Voer uit",
+    "Due date" : "Sperdatum",
     "Share" : "Deel",
-    "Personal" : "Persoonlik"
+    "Personal" : "Persoonlik",
+    "Save" : "Stoor",
+    "Keyboard shortcuts" : "Sneltoetse",
+    "Keyboard shortcut" : "Snelsleutel",
+    "Today" : "Vandag",
+    "Tomorrow" : "Môre"
 },
 "nplurals=2; plural=(n != 1);");
