@@ -14,6 +14,8 @@ OC.L10N.register(
     "Cancel" : "Sguir dheth",
     "Completed" : "Coileanta",
     "Details" : "Mion-fhiosrachadh",
+    "General" : "Coitcheann",
+    "Search" : "Lorg",
     "Sharing" : "Co-roinneadh",
     "Tags" : "Tagaichean",
     "Activity" : "Gnìomhachd",
@@ -22,12 +24,11 @@ OC.L10N.register(
     "Delete" : "Sguab às",
     "Edit" : "Deasaich",
     "Download" : "Luchdaich a-nuas",
-    "Save" : "Sàbhail",
     "seconds ago" : "diog air ais",
-    "Search" : "Lorg",
     "No notifications" : "Gun bhrath",
-    "Today" : "An-diugh",
     "Close" : "Dùin",
-    "Share" : "Co-roinn"
+    "Share" : "Co-roinn",
+    "Save" : "Sàbhail",
+    "Today" : "An-diugh"
 },
 "nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
