@@ -140,6 +140,11 @@ OC.L10N.register(
     "Toggle compact mode" : "החלפת מצב חסכוני",
     "Open details" : "פתיחת פרטים",
     "Details" : "פרטים",
+    "General" : "כללי",
+    "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
+    "Appearance" : "מראה",
+    "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
+    "Search" : "חיפוש",
     "Loading board" : "הלוח נטען",
     "Board not found" : "הלוח לא נמצא",
     "Create a new list to add cards to this board" : "צור רשימה חדשה כדי להוסיף כרטיסים ללוח זה",
@@ -190,7 +195,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "אין עדיין הערות. אפשר להתחיל לדון!",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
-    "Save" : "שמור",
     "Created:" : "מועד היצירה:",
     "In reply to" : "בתגובה אל",
     "Reply" : "תגובה",
@@ -217,16 +221,9 @@ OC.L10N.register(
     "Unassign myself" : "לבטל את הקצאת עצמי",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "seconds ago" : "לפני מספר שניות",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
-    "Keyboard shortcut" : "קיצור מקלדת",
-    "Action" : "פעולה",
-    "Shift" : "הזזה",
-    "Search" : "חיפוש",
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
-    "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
-    "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
     "Cancel edit" : "בטל עריכה",
     "Board {0} deleted" : "הלוח {0} נמחק",
     "All cards" : "כל הכרטיסים",
@@ -270,6 +267,11 @@ OC.L10N.register(
     "Example Task 3" : "משימה לדוגמה 3",
     "Example Task 2" : "משימה לדוגמה 2",
     "Example Task 1" : "משימה לדוגמה 1",
+    "Save" : "שמור",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Keyboard shortcut" : "קיצור מקלדת",
+    "Action" : "פעולה",
+    "Shift" : "הזזה",
     "Today" : "היום",
     "Tomorrow" : "מחר",
     "No due" : "אין תאריך יעד"
