@@ -143,6 +143,11 @@ OC.L10N.register(
     "Toggle compact mode" : "Prebaci u kompaktni način rada",
     "Open details" : "Otvori pojedinosti",
     "Details" : "Pojedinosti",
+    "General" : "Općenito",
+    "Use bigger card view" : "Prikaži veće kartice",
+    "Appearance" : "Izgled",
+    "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
+    "Search" : "Traži",
     "Loading board" : "Učitavanje ploče",
     "Board not found" : "Ploča nije pronađena",
     "Create a new list to add cards to this board" : "Stvorite novi popis kako biste dodali kartice na ovu ploču",
@@ -194,7 +199,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "Nema komentara. Započnite raspravu!",
     "The comment cannot be empty." : "Komentar ne može biti prazan.",
     "The comment cannot be longer than 1000 characters." : "Komentar ne može duži od 1000 znakova.",
-    "Save" : "Spremi",
     "Created:" : "Stvoreno:",
     "In reply to" : "Kao odgovor",
     "Cancel reply" : "Prekini odgovor",
@@ -224,16 +228,9 @@ OC.L10N.register(
     "Unassign myself" : "Ukloni sebe",
     "Delete card" : "Izbriši karticu",
     "seconds ago" : "prije nekoliko sekundi",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
-    "Keyboard shortcut" : "Tipkovni prečac",
-    "Action" : "Radnja",
-    "Shift" : "Pomakni",
-    "Search" : "Traži",
     "All boards" : "Sve ploče",
     "Archived boards" : "Arhivirane ploče",
     "Shared with you" : "Podijeljeno s vama",
-    "Use bigger card view" : "Prikaži veće kartice",
-    "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
     "Cancel edit" : "Otkaži uređivanje",
     "Board {0} deleted" : "Ploča {0} je izbrisana",
     "All cards" : "Sve kartice",
@@ -288,6 +285,11 @@ OC.L10N.register(
     "Example Task 3" : "Primjer zadatka 3.",
     "Example Task 2" : "Primjer zadatka 2.",
     "Example Task 1" : "Primjer zadatka 1.",
+    "Save" : "Spremi",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Keyboard shortcut" : "Tipkovni prečac",
+    "Action" : "Radnja",
+    "Shift" : "Pomakni",
     "Today" : "Danas",
     "Tomorrow" : "Sutra",
     "No due" : "Nema nezavršenih"
