@@ -87,7 +87,6 @@ OC.L10N.register(
     "Load more" : "더 불러오기",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "\"%s\"의 \"%s\" 카드가 %s에 의해 당신에게 할당되었습니다.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user}님이 {deck-board}의 {deck-card} 카드를 당신에게 할당했습니다.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
     "The card {deck-card} on {deck-board} has reached its due date." : "{deck-board}의 {deck-card} 카드가 만기일에 도달했습니다.",
     "%s has mentioned you in a comment on \"%s\"." : "%s 님이 \"%s\"에 대한 댓글에서 당신을 언급했습니다.",
     "{user} has mentioned you in a comment on {deck-card}." : "{user}님이 {deck-card}의 댓글에서 당신을 언급했습니다.",
@@ -167,6 +166,30 @@ OC.L10N.register(
     "Show card cover images" : "카드 표지 이미지 표시",
     "Open details" : "자세한 정보 열기",
     "Details" : "세부사항",
+    "Deck settings" : "Deck 설정",
+    "General" : "일반",
+    "Use bigger card view" : "카드 크게 보기 사용",
+    "Appearance" : "외형",
+    "Show card ID badge" : "카드 ID 배지 표시",
+    "Show boards in calendar/tasks" : "캘린더/작업에 보드 표시",
+    "Admin settings" : "관리자 설정",
+    "Limit board creation to some groups" : "보드 생성을 일부 그룹으로 제한",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "해당 그룹 외부의 사용자는 자신의 보드를 만들 수 없지만 공유된 보드에서는 계속 작업할 수 있습니다.",
+    "Board actions" : "보드 동작",
+    "Scroll sideways" : "옆으로 스크롤",
+    "Navigate between cards" : "카드 간 이동",
+    "Close card details" : "카드 세부정보 닫기",
+    "Search" : "검색",
+    "Show card filters" : "카드 필터 표시",
+    "Clear card filters" : "카드 필터 초기화",
+    "Show those shortcuts" : "다음 단축키 표시",
+    "Card actions" : "카드 동작",
+    "Open card details" : "카드 세부정보 열기",
+    "Edit the card title" : "카드 제목 수정",
+    "Assign yourself to the current card" : "현재 카드에 자신을 할당",
+    "Archive/unarchive the current card" : "현재 카드 보관/보관 취소",
+    "Mark card as completed/not completed" : "카드를 완료됨/완료되지 않음으로 표시",
+    "Open card menu" : "카드 메뉴 열기",
     "Currently present people" : "현재 존재하는 사람들",
     "Loading board" : "보드 불러오는 중",
     "Board not found" : "보드를 찾을 수 없음",
@@ -233,7 +256,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "아직 댓글이 없습니다. 토론을 시작하세요!",
     "The comment cannot be empty." : "댓글은 공백일 수 없습니다.",
     "The comment cannot be longer than 1000 characters." : "설명은 1000자를 초과할 수 없습니다.",
-    "Save" : "저장",
     "Created:" : "생성한 날짜:",
     "In reply to" : "답장",
     "Cancel reply" : "응답 취소",
@@ -281,41 +303,9 @@ OC.L10N.register(
     "Mark as not done" : "완료되지 않은 것으로 표시",
     "Delete card" : "카드 삭제",
     "seconds ago" : "초 전",
-    "Keyboard shortcuts" : "키보드 단축키",
-    "Boost your productivity using Deck with keyboard shortcuts." : "키보드 단축키가 포함된 Deck을 사용하여 생산성을 높이세요.",
-    "Board actions" : "보드 동작",
-    "Keyboard shortcut" : "키보드 단축키",
-    "Action" : "동작",
-    "Shift" : "Shift",
-    "Scroll" : "스크롤",
-    "Scroll sideways" : "옆으로 스크롤",
-    "Navigate between cards" : "카드 간 이동",
-    "Esc" : "Esc",
-    "Close card details" : "카드 세부정보 닫기",
-    "Ctrl" : "Ctrl",
-    "Search" : "검색",
-    "Show card filters" : "카드 필터 표시",
-    "Clear card filters" : "카드 필터 초기화",
-    "Show help dialog" : "도움말 대화 상자 표시",
-    "Card actions" : "카드 동작",
-    "The following actions can be triggered on the currently highlighted card" : "현재 강조 표시된 카드에서 다음 작업이 실행될 수 있습니다.",
-    "Enter" : "Enter",
-    "Space" : "Space",
-    "Open card details" : "카드 세부정보 열기",
-    "Edit the card title" : "카드 제목 수정",
-    "Assign yourself to the current card" : "현재 카드에 자신을 할당",
-    "Archive/unarchive the current card" : "현재 카드 보관/보관 취소",
-    "Mark card as completed/not completed" : "카드를 완료됨/완료되지 않음으로 표시",
-    "Open card menu" : "카드 메뉴 열기",
     "All boards" : "모든 보드",
     "Archived boards" : "보관된 게시판",
     "Shared with you" : "나와 공유됨",
-    "Deck settings" : "Deck 설정",
-    "Use bigger card view" : "카드 크게 보기 사용",
-    "Show card ID badge" : "카드 ID 배지 표시",
-    "Show boards in calendar/tasks" : "캘린더/작업에 보드 표시",
-    "Limit board creation to some groups" : "보드 생성을 일부 그룹으로 제한",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "해당 그룹 외부의 사용자는 자신의 보드를 만들 수 없지만 공유된 보드에서는 계속 작업할 수 있습니다.",
     "Cancel edit" : "편집 취소",
     "Board {0} deleted" : "보드 {0}개가 삭제되었습니다.",
     "All cards" : "모든 카드",
@@ -342,9 +332,6 @@ OC.L10N.register(
     "Export as CSV" : "CSV로 내보내기",
     "Export" : "내보내기",
     "Loading filtered view" : "필터링된 보기 불러오는 중",
-    "Today" : "오늘",
-    "Tomorrow" : "내일",
-    "No due" : "기한 없음",
     "Search for {searchQuery} in all boards" : "모든 게시판에서 {searchQuery}를 검색하세요",
     "No results found" : "결과 없음",
     "Deck board {name}\n* Last modified on {lastMod}" : "데크 보드 {name}\n* 마지막 수정일 {lastMod}",
@@ -379,11 +366,27 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "Deck 카드와 함께 {file} 공유",
     "Share" : "공유",
     "Personal" : "개인",
+    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
     "To do" : "할 일",
     "Doing" : "하는 중",
     "Example Task 3" : "작업 예제 3",
     "Example Task 2" : "작업 예제 2",
     "Example Task 1" : "작업 예제 1",
-    "Move card to another board" : "카드를 다른 보드로 이동"
+    "Save" : "저장",
+    "Keyboard shortcuts" : "키보드 단축키",
+    "Boost your productivity using Deck with keyboard shortcuts." : "키보드 단축키가 포함된 Deck을 사용하여 생산성을 높이세요.",
+    "Keyboard shortcut" : "키보드 단축키",
+    "Action" : "동작",
+    "Shift" : "Shift",
+    "Scroll" : "스크롤",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "도움말 대화 상자 표시",
+    "The following actions can be triggered on the currently highlighted card" : "현재 강조 표시된 카드에서 다음 작업이 실행될 수 있습니다.",
+    "Enter" : "Enter",
+    "Space" : "Space",
+    "Today" : "오늘",
+    "Tomorrow" : "내일",
+    "No due" : "기한 없음"
 },
 "nplurals=1; plural=0;");
