@@ -272,7 +272,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "尚無意見，開始討論吧！",
     "The comment cannot be empty." : "意見不能為空。",
     "The comment cannot be longer than 1000 characters." : "意見不能超過 1000 個字符。",
-    "Save" : "保存",
     "Created:" : "建立：",
     "In reply to" : "回覆",
     "Cancel reply" : "取消回覆",
@@ -334,6 +333,10 @@ OC.L10N.register(
     "An error occurred" : "發生錯誤",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "你確定你要刪除 {title} 面板嗎？面板內所有數據(包括已封存的卡片)都將因此被刪除。",
     "Delete the board?" : "是否刪除面板？",
+    "Are you sure you want to leave the board {title}?" : "您確定您想要離開看板 {title} 嗎？",
+    "Leave the board?" : "離開面板？",
+    "Leave" : "離開",
+    "Failed to leave the board" : "無法離開面板",
     "Exporting board..." : "正在導出面板 ...",
     "Board details" : "面板詳情",
     "Edit board" : "編輯面板",
@@ -347,6 +350,7 @@ OC.L10N.register(
     "Assigned cards" : "分配的卡片",
     "No notifications" : "無通知",
     "Delete board" : "刪除面板",
+    "Leave board" : "離開面板",
     "Importing board..." : "正在導入面板 ...",
     "Board imported successfully" : "面板成功導入",
     "Import board" : "導入面板",
@@ -407,6 +411,7 @@ OC.L10N.register(
     "Example Task 3" : "示例任務 3",
     "Example Task 2" : "示例任務 2",
     "Example Task 1" : "示例任務 1",
+    "Save" : "保存",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
     "Boost your productivity using Deck with keyboard shortcuts." : "提高您的生產力，在 Deck 上使用鍵盤快捷鍵。",
     "Keyboard shortcut" : "鍵盤快捷鍵",
