@@ -181,6 +181,30 @@ OC.L10N.register(
     "Show card cover images" : "顯示卡片封面影像",
     "Open details" : "開啟細節",
     "Details" : "詳細資料",
+    "Deck settings" : "Deck 設定",
+    "General" : "一般",
+    "Use bigger card view" : "使用較大的卡片檢視",
+    "Appearance" : "外觀",
+    "Show card ID badge" : "顯示卡片 ID 徽章",
+    "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
+    "Admin settings" : "管理員設定",
+    "Limit board creation to some groups" : "限制僅某些群組可建立看板",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
+    "Board actions" : "看板動作",
+    "Scroll sideways" : "橫向捲軸",
+    "Navigate between cards" : "在卡片間移動",
+    "Close card details" : "關閉卡片詳細資訊",
+    "Search" : "搜尋",
+    "Show card filters" : "顯示卡片篩選條件",
+    "Clear card filters" : "清除卡片篩選條件",
+    "Show those shortcuts" : "顯示這些快捷鍵",
+    "Card actions" : "卡片動作",
+    "Open card details" : "開啟卡片詳細資訊",
+    "Edit the card title" : "編輯卡片標題",
+    "Assign yourself to the current card" : "將自己指派給目前的卡片",
+    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
+    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
+    "Open card menu" : "開啟卡片選單",
     "Currently present people" : "目前在場夥伴",
     "Loading board" : "正在載入佈告欄",
     "Board not found" : "找不到佈告欄",
@@ -248,7 +272,6 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "暫無留言。開始討論吧！",
     "The comment cannot be empty." : "留言不能為空。",
     "The comment cannot be longer than 1000 characters." : "留言不能多於 1000 個字元。",
-    "Save" : "儲存",
     "Created:" : "建立：",
     "In reply to" : "回覆",
     "Cancel reply" : "取消回覆",
@@ -298,41 +321,9 @@ OC.L10N.register(
     "Mark as not done" : "標記為未完成",
     "Delete card" : "刪除卡片",
     "seconds ago" : "幾秒前",
-    "Keyboard shortcuts" : "鍵盤快速鍵",
-    "Boost your productivity using Deck with keyboard shortcuts." : "在 Deck 上利用鍵盤快捷鍵提高您的生產力。",
-    "Board actions" : "看板動作",
-    "Keyboard shortcut" : "鍵盤快捷鍵",
-    "Action" : "動作",
-    "Shift" : "Shift",
-    "Scroll" : "捲軸",
-    "Scroll sideways" : "橫向捲軸",
-    "Navigate between cards" : "在卡片間移動",
-    "Esc" : "Esc",
-    "Close card details" : "關閉卡片詳細資訊",
-    "Ctrl" : "Ctrl",
-    "Search" : "搜尋",
-    "Show card filters" : "顯示卡片篩選條件",
-    "Clear card filters" : "清除卡片篩選條件",
-    "Show help dialog" : "顯示說明對話方塊",
-    "Card actions" : "卡片動作",
-    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下動作",
-    "Enter" : "輸入",
-    "Space" : "空間",
-    "Open card details" : "開啟卡片詳細資訊",
-    "Edit the card title" : "編輯卡片標題",
-    "Assign yourself to the current card" : "將自己指派給目前的卡片",
-    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
-    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
-    "Open card menu" : "開啟卡片選單",
     "All boards" : "所有佈告欄",
     "Archived boards" : "已封存的佈告欄",
     "Shared with you" : "與您分享",
-    "Deck settings" : "Deck 設定",
-    "Use bigger card view" : "使用較大的卡片檢視",
-    "Show card ID badge" : "顯示卡片 ID 徽章",
-    "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
-    "Limit board creation to some groups" : "限制僅某些群組可建立看板",
-    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
     "Cancel edit" : "取消編輯",
     "Save board" : "儲存佈告欄",
     "Board {0} deleted" : "已刪除佈告欄 {0}",
@@ -342,6 +333,10 @@ OC.L10N.register(
     "An error occurred" : "發生錯誤",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料，包含封存的卡片。",
     "Delete the board?" : "刪除佈告欄？",
+    "Are you sure you want to leave the board {title}?" : "您確定您想要離開看板 {title} 嗎？",
+    "Leave the board?" : "離開看板？",
+    "Leave" : "離開",
+    "Failed to leave the board" : "無法離開看板",
     "Exporting board..." : "正在匯出看板……",
     "Board details" : "佈告欄詳細資訊",
     "Edit board" : "編輯佈告欄",
@@ -355,6 +350,7 @@ OC.L10N.register(
     "Assigned cards" : "已分配的卡片",
     "No notifications" : "無通知",
     "Delete board" : "刪除佈告欄",
+    "Leave board" : "離開看板",
     "Importing board..." : "正在匯入看板……",
     "Board imported successfully" : "已成功匯入看板",
     "Import board" : "匯入看板",
@@ -415,6 +411,19 @@ OC.L10N.register(
     "Example Task 3" : "範例工作 3",
     "Example Task 2" : "範例工作 2",
     "Example Task 1" : "範例工作 1",
+    "Save" : "儲存",
+    "Keyboard shortcuts" : "鍵盤快速鍵",
+    "Boost your productivity using Deck with keyboard shortcuts." : "在 Deck 上利用鍵盤快捷鍵提高您的生產力。",
+    "Keyboard shortcut" : "鍵盤快捷鍵",
+    "Action" : "動作",
+    "Shift" : "Shift",
+    "Scroll" : "捲軸",
+    "Esc" : "Esc",
+    "Ctrl" : "Ctrl",
+    "Show help dialog" : "顯示說明對話方塊",
+    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下動作",
+    "Enter" : "輸入",
+    "Space" : "空間",
     "Today" : "今天",
     "Tomorrow" : "明天",
     "No due" : "無到期日"
