@@ -1,24 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2018 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Command;
@@ -29,6 +13,7 @@ use OCA\Deck\Db\CardMapper;
 use OCA\Deck\Db\StackMapper;
 use OCA\Deck\Model\CardDetails;
 use OCA\Deck\Service\BoardService;
+use OCA\Deck\Service\CommentService;
 use OCP\App\IAppManager;
 use OCP\DB\Exception;
 use Symfony\Component\Console\Command\Command;
@@ -44,6 +29,7 @@ class UserExport extends Command {
 		private StackMapper $stackMapper,
 		private CardMapper $cardMapper,
 		private AssignmentMapper $assignedUsersMapper,
+		private CommentService $commentService,
 	) {
 		parent::__construct();
 	}
@@ -73,6 +59,10 @@ class UserExport extends Command {
 
 		$data = [];
 		foreach ($boards as $board) {
+			if ($board->getDeletedAt() > 0) {
+				continue;
+			}
+
 			$fullBoard = $this->boardMapper->find($board->getId(), true, true);
 			$data[$board->getId()] = $fullBoard->jsonSerialize();
 			$stacks = $this->stackMapper->findAll($board->getId());
@@ -80,12 +70,21 @@ class UserExport extends Command {
 				$data[$board->getId()]['stacks'][$stack->getId()] = $stack->jsonSerialize();
 				$cards = $this->cardMapper->findAllByStack($stack->getId());
 				foreach ($cards as $card) {
+					if ($card->getDeletedAt() > 0) {
+						continue;
+					}
 					$fullCard = $this->cardMapper->find($card->getId());
+
 					$assignedUsers = $this->assignedUsersMapper->findAll($card->getId());
 					$fullCard->setAssignedUsers($assignedUsers);
 
 					$cardDetails = new CardDetails($fullCard, $fullBoard);
-					$data[$board->getId()]['stacks'][$stack->getId()]['cards'][] = $cardDetails->jsonSerialize();
+					$comments = $this->commentService->list($card->getId());
+					$cardDetails->setCommentsCount(count($comments->getData()));
+
+					$cardJson = $cardDetails->jsonSerialize();
+					$cardJson['comments'] = $comments->getData();
+					$data[$board->getId()]['stacks'][$stack->getId()]['cards'][] = $cardJson;
 				}
 			}
 		}
