@@ -1,5 +1,9 @@
 <?php
 
+/**
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
 namespace OCA\Deck\Reference;
 
 use OCA\Deck\AppInfo\Application;
@@ -10,10 +14,12 @@ use OCP\IL10N;
 use OCP\IURLGenerator;
 
 class CreateCardReferenceProvider extends ADiscoverableReferenceProvider {
+
 	public function __construct(
 		private IL10N $l10n,
 		private IURLGenerator $urlGenerator,
-		private ?string $userId) {
+		private ?string $userId,
+	) {
 	}
 
 	/**
