@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -21,7 +22,7 @@ class BoardSearchResultEntry extends SearchResultEntry {
 			),
 			$board->getTitle(),
 			'',
-			$urlGenerator->linkToRouteAbsolute('deck.page.index') . '#/board/' . $board->getId(),
+			$urlGenerator->linkToRouteAbsolute('deck.page.indexBoard', ['boardId' => $board->getId()]),
 			'icon-deck');
 	}
 }
