@@ -1,24 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 declare(strict_types=1);
@@ -46,7 +30,7 @@ class ConfigService {
 
 	public function __construct(
 		IConfig $config,
-		IGroupManager $groupManager
+		IGroupManager $groupManager,
 	) {
 		$this->groupManager = $groupManager;
 		$this->config = $config;
@@ -110,7 +94,7 @@ class ConfigService {
 		return false;
 	}
 
-	public function isCalendarEnabled(int $boardId = null): bool {
+	public function isCalendarEnabled(?int $boardId = null): bool {
 		if ($this->getUserId() === null) {
 			return false;
 		}
@@ -124,7 +108,7 @@ class ConfigService {
 		return (bool)$this->config->getUserValue($this->getUserId(), Application::APP_ID, 'board:' . $boardId . ':calendar', $defaultState);
 	}
 
-	public function isCardDetailsInModal(int $boardId = null): bool {
+	public function isCardDetailsInModal(?int $boardId = null): bool {
 		if ($this->getUserId() === null) {
 			return false;
 		}
@@ -223,11 +207,19 @@ class ConfigService {
 		return array_filter($groups);
 	}
 
-	public function getAttachmentFolder(string $userId = null): string {
+	public function getAttachmentFolder(?string $userId = null): string {
 		if ($userId === null && $this->getUserId() === null) {
 			throw new NoPermissionException('Must be logged in get the attachment folder');
 		}
 
 		return $this->config->getUserValue($userId ?? $this->getUserId(), 'deck', 'attachment_folder', '/Deck');
 	}
+
+	public function setAttachmentFolder(?string $userId, string $path): void {
+		if ($userId === null && $this->getUserId() === null) {
+			throw new NoPermissionException('Must be logged in get the attachment folder');
+		}
+
+		$this->config->setUserValue($userId ?? $this->getUserId(), 'deck', 'attachment_folder', $path);
+	}
 }
