@@ -1,34 +1,18 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
 
+use OCA\Deck\BadRequestException;
+use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\Label;
-use OCA\Deck\Db\Acl;
 use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\StatusException;
-use OCA\Deck\BadRequestException;
 use OCA\Deck\Validators\LabelServiceValidator;
 
 class LabelService {
@@ -49,8 +33,8 @@ class LabelService {
 		PermissionService $permissionService,
 		BoardService $boardService,
 		ChangeHelper $changeHelper,
-		LabelServiceValidator $labelServiceValidator
-		) {
+		LabelServiceValidator $labelServiceValidator,
+	) {
 		$this->labelMapper = $labelMapper;
 		$this->permissionService = $permissionService;
 		$this->boardService = $boardService;
@@ -109,6 +93,18 @@ class LabelService {
 		return $this->labelMapper->insert($label);
 	}
 
+	public function cloneLabelIfNotExists(int $labelId, int $targetBoardId): Label {
+		$this->permissionService->checkPermission(null, $targetBoardId, Acl::PERMISSION_MANAGE);
+		$boardLabels = $this->boardService->find($targetBoardId)->getLabels();
+		$originLabel = $this->find($labelId);
+		$filteredValues = array_values(array_filter($boardLabels, fn ($item) => $item->getTitle() === $originLabel->getTitle()));
+		if (empty($filteredValues)) {
+			$label = $this->create($originLabel->getTitle(), $originLabel->getColor(), $targetBoardId);
+			return $label;
+		}
+		return $originLabel;
+	}
+
 	/**
 	 * @param $id
 	 * @return \OCP\AppFramework\Db\Entity
