@@ -3,37 +3,19 @@
 declare(strict_types=1);
 
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- * @author Maxence Lange <maxence@artificial-owl.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
 
 use OCA\Deck\Db\AssignmentMapper;
 use OCA\Deck\Db\Board;
+use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\CardMapper;
+use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\Model\CardDetails;
 use OCP\Comments\ICommentsManager;
-use OCA\Deck\Db\BoardMapper;
-use OCA\Deck\Db\LabelMapper;
 use OCP\IUserManager;
 
 class OverviewService {
@@ -54,7 +36,7 @@ class OverviewService {
 		AssignmentMapper $assignedUsersMapper,
 		IUserManager $userManager,
 		ICommentsManager $commentsManager,
-		AttachmentService $attachmentService
+		AttachmentService $attachmentService,
 	) {
 		$this->cardService = $cardService;
 		$this->boardMapper = $boardMapper;
