@@ -1,24 +1,8 @@
 <?php
-/*
- * @copyright Copyright (c) 2021 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+
+/**
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 declare(strict_types=1);
@@ -63,7 +47,7 @@ class SearchService {
 		FilterStringParser $filterStringParser,
 		IUserManager $userManager,
 		IL10N $l10n,
-		IURLGenerator $urlGenerator
+		IURLGenerator $urlGenerator,
 	) {
 		$this->boardService = $boardService;
 		$this->cardMapper = $cardMapper;
@@ -75,7 +59,7 @@ class SearchService {
 		$this->urlGenerator = $urlGenerator;
 	}
 
-	public function searchCards(string $term, int $limit = null, ?int $cursor = null): array {
+	public function searchCards(string $term, ?int $limit = null, ?int $cursor = null): array {
 		$boards = $this->boardService->getUserBoards();
 		$boardIds = array_map(static function (Board $board) {
 			return $board->getId();
@@ -115,8 +99,7 @@ class SearchService {
 			$card = Card::fromRow($cardRow);
 			// TODO: Only perform one enrich call here
 			$self->cardService->enrichCards([$card]);
-			$user = $this->userManager->get($comment->getActorId());
-			$displayName = $user ? $user->getDisplayName() : '';
+			$displayName = $this->userManager->getDisplayName($comment->getActorId()) ?? '';
 			return new CommentSearchResultEntry($comment->getId(), $comment->getMessage(), $displayName, $card, $this->urlGenerator, $this->l10n);
 		}, $matchedComments);
 	}
