@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -46,7 +47,7 @@ class ShareAPIHelper {
 		$boardId = $this->cardMapper->findBoardId($card->getId());
 		$result['share_with'] = $share->getSharedWith();
 		$result['share_with_displayname'] = $card->getTitle();
-		$result['share_with_link'] = $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . '#/board/' . $boardId . '/card/' . $card->getId();
+		$result['share_with_link'] = $this->urlGenerator->linkToRouteAbsolute('deck.page.indexCard', ['boardId' => $boardId, 'cardId' => $card->getId()]);
 		return $result;
 	}
 
